# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.27.1](https://github.com/conda/rattler/compare/rattler_lock-v0.27.0...rattler_lock-v0.27.1) - 2026-03-18

### Other

- update Cargo.toml dependencies

## [0.27.0](https://github.com/conda/rattler/compare/rattler_lock-v0.26.16...rattler_lock-v0.27.0) - 2026-03-16

### Added

- [**breaking**] Make name in MatchSpec non-optional ([#2132](https://github.com/conda/rattler/pull/2132))

## [0.26.16](https://github.com/conda/rattler/compare/rattler_lock-v0.26.15...rattler_lock-v0.26.16) - 2026-02-25

### Other

- updated the following local packages: rattler_conda_types, rattler_solve

## [0.26.15](https://github.com/conda/rattler/compare/rattler_lock-v0.26.14...rattler_lock-v0.26.15) - 2026-02-20

### Other

- updated the following local packages: rattler_conda_types, rattler_solve

## [0.26.14](https://github.com/conda/rattler/compare/rattler_lock-v0.26.13...rattler_lock-v0.26.14) - 2026-02-19

### Other

- Typo and clippy fixes ([#2047](https://github.com/conda/rattler/pull/2047))

## [0.26.13](https://github.com/conda/rattler/compare/rattler_lock-v0.26.12...rattler_lock-v0.26.13) - 2026-02-04

### Other

- updated the following local packages: rattler_conda_types, rattler_solve

## [0.26.12](https://github.com/conda/rattler/compare/rattler_lock-v0.26.11...rattler_lock-v0.26.12) - 2026-01-22

### Other

- updated the following local packages: rattler_conda_types, rattler_solve

## [0.26.11](https://github.com/baszalmstra/rattler/compare/rattler_lock-v0.26.10...rattler_lock-v0.26.11) - 2026-01-22

### Fixed

- changelog

## [0.26.10](https://github.com/conda/rattler/compare/rattler_lock-v0.26.9...rattler_lock-v0.26.10) - 2026-01-22

### Added

- add support for `packages.whl` and wheel archives types ([#1988](https://github.com/conda/rattler/pull/1988))

### Other

- add type for archive file name ([#1999](https://github.com/conda/rattler/pull/1999))
- remove Lockfile v5 serializing ([#1973](https://github.com/conda/rattler/pull/1973))

## [0.26.9](https://github.com/conda/rattler/compare/rattler_lock-v0.26.8...rattler_lock-v0.26.9) - 2025-12-18

### Fixed

- always emit depends in index.json ([#1932](https://github.com/conda/rattler/pull/1932))

### Other

- update README.md with new banner image ([#1926](https://github.com/conda/rattler/pull/1926))

## [0.26.8](https://github.com/conda/rattler/compare/rattler_lock-v0.26.7...rattler_lock-v0.26.8) - 2025-12-08

### Other

- update Cargo.toml dependencies

## [0.26.7](https://github.com/conda/rattler/compare/rattler_lock-v0.26.6...rattler_lock-v0.26.7) - 2025-11-27

### Added

- add `variants` to the lock-file (v6) ([#1854](https://github.com/conda/rattler/pull/1854))
- *(rattler_lock)* add prerelease-mode support for PyPI dependencies ([#1889](https://github.com/conda/rattler/pull/1889))

## [0.26.6](https://github.com/conda/rattler/compare/rattler_lock-v0.26.5...rattler_lock-v0.26.6) - 2025-11-25

### Other

- updated the following local packages: rattler_conda_types, rattler_solve

## [0.26.5](https://github.com/conda/rattler/compare/rattler_lock-v0.26.4...rattler_lock-v0.26.5) - 2025-11-22

### Other

- updated the following local packages: rattler_conda_types, rattler_solve

## [0.26.4](https://github.com/conda/rattler/compare/rattler_lock-v0.26.3...rattler_lock-v0.26.4) - 2025-11-20

### Other

- updated the following local packages: rattler_conda_types, rattler_solve

## [0.26.3](https://github.com/conda/rattler/compare/rattler_lock-v0.26.2...rattler_lock-v0.26.3) - 2025-11-19

### Other

- updated the following local packages: rattler_conda_types, rattler_solve

## [0.26.2](https://github.com/conda/rattler/compare/rattler_lock-v0.26.1...rattler_lock-v0.26.2) - 2025-11-13

### Added

- Add glob support for package name in matchspec ([#1480](https://github.com/conda/rattler/pull/1480))

## [0.26.1](https://github.com/conda/rattler/compare/rattler_lock-v0.26.0...rattler_lock-v0.26.1) - 2025-10-28

### Fixed

- timestamp serialization as milliseconds ([#1776](https://github.com/conda/rattler/pull/1776))

### Other

- Replace fxhash with ahash ([#1674](https://github.com/conda/rattler/pull/1674))

## [0.26.0](https://github.com/conda/rattler/compare/rattler_lock-v0.25.3...rattler_lock-v0.26.0) - 2025-10-25

### Added

- *(lock)* add path to package_build_source ([#1719](https://github.com/conda/rattler/pull/1719))

## [0.25.3](https://github.com/conda/rattler/compare/rattler_lock-v0.25.2...rattler_lock-v0.25.3) - 2025-10-18

### Other

- updated the following local packages: rattler_conda_types, rattler_solve

## [0.25.2](https://github.com/conda/rattler/compare/rattler_lock-v0.25.1...rattler_lock-v0.25.2) - 2025-10-17

### Other

- updated the following local packages: rattler_digest, rattler_conda_types, rattler_solve

## [0.25.1](https://github.com/conda/rattler/compare/rattler_lock-v0.25.0...rattler_lock-v0.25.1) - 2025-10-14

### Other

- updated the following local packages: rattler_digest, rattler_conda_types, rattler_solve

## [0.25.0](https://github.com/conda/rattler/compare/rattler_lock-v0.24.2...rattler_lock-v0.25.0) - 2025-10-03

### Fixed

- *(lock)* package build source ([#1699](https://github.com/conda/rattler/pull/1699))

## [0.24.2](https://github.com/conda/rattler/compare/rattler_lock-v0.24.1...rattler_lock-v0.24.2) - 2025-09-30

### Other

- updated the following local packages: rattler_conda_types, rattler_solve

## [0.24.1](https://github.com/conda/rattler/compare/rattler_lock-v0.24.0...rattler_lock-v0.24.1) - 2025-09-05

### Other

- updated the following local packages: rattler_conda_types, rattler_solve

## [0.24.0](https://github.com/conda/rattler/compare/rattler_lock-v0.23.16...rattler_lock-v0.24.0) - 2025-09-04

### Added

- lock package build source ([#1650](https://github.com/conda/rattler/pull/1650))

## [0.23.16](https://github.com/conda/rattler/compare/rattler_lock-v0.23.15...rattler_lock-v0.23.16) - 2025-09-02

### Other

- updated the following local packages: rattler_conda_types, rattler_solve

## [0.23.15](https://github.com/conda/rattler/compare/rattler_lock-v0.23.14...rattler_lock-v0.23.15) - 2025-08-15

### Other

- updated the following local packages: rattler_conda_types, rattler_solve

## [0.23.14](https://github.com/conda/rattler/compare/rattler_lock-v0.23.13...rattler_lock-v0.23.14) - 2025-08-12

### Other

- updated the following local packages: rattler_conda_types, rattler_solve

## [0.23.13](https://github.com/conda/rattler/compare/rattler_lock-v0.23.12...rattler_lock-v0.23.13) - 2025-07-23

### Fixed

- indexing `extra-depends` ([#1546](https://github.com/conda/rattler/pull/1546))

## [0.23.12](https://github.com/conda/rattler/compare/rattler_lock-v0.23.11...rattler_lock-v0.23.12) - 2025-07-21

### Other

- bump rust 1.88.0 ([#1536](https://github.com/conda/rattler/pull/1536))

## [0.23.11](https://github.com/conda/rattler/compare/rattler_lock-v0.23.10...rattler_lock-v0.23.11) - 2025-07-14

### Other

- updated the following local packages: rattler_conda_types, rattler_solve

## [0.23.10](https://github.com/conda/rattler/compare/rattler_lock-v0.23.9...rattler_lock-v0.23.10) - 2025-07-09

### Other

- updated the following local packages: rattler_conda_types, rattler_solve

## [0.23.9](https://github.com/conda/rattler/compare/rattler_lock-v0.23.8...rattler_lock-v0.23.9) - 2025-07-01

### Fixed

- *(ci)* run pre-commit-run for all files ([#1481](https://github.com/conda/rattler/pull/1481))

## [0.23.8](https://github.com/conda/rattler/compare/rattler_lock-v0.23.7...rattler_lock-v0.23.8) - 2025-06-26

### Other

- updated the following local packages: rattler_conda_types, rattler_solve

## [0.23.7](https://github.com/conda/rattler/compare/rattler_lock-v0.23.6...rattler_lock-v0.23.7) - 2025-06-25

### Other

- updated the following local packages: rattler_conda_types, rattler_solve

## [0.23.6](https://github.com/conda/rattler/compare/rattler_lock-v0.23.5...rattler_lock-v0.23.6) - 2025-06-23

### Other

- update npm name ([#1368](https://github.com/conda/rattler/pull/1368))
- update readme ([#1364](https://github.com/conda/rattler/pull/1364))

## [0.23.5](https://github.com/conda/rattler/compare/rattler_lock-v0.23.4...rattler_lock-v0.23.5) - 2025-05-23

### Other

- updated the following local packages: rattler_conda_types, rattler_solve

## [0.23.4](https://github.com/conda/rattler/compare/rattler_lock-v0.23.3...rattler_lock-v0.23.4) - 2025-05-16

### Other

- update Cargo.toml dependencies

## [0.23.3](https://github.com/conda/rattler/compare/rattler_lock-v0.23.2...rattler_lock-v0.23.3) - 2025-05-03

### Other

- lock workspace member dependencies ([#1279](https://github.com/conda/rattler/pull/1279))

## [0.23.2](https://github.com/conda/rattler/compare/rattler_lock-v0.23.1...rattler_lock-v0.23.2) - 2025-04-17

### Fixed

- rename struct and reexport ([#1262](https://github.com/conda/rattler/pull/1262))

## [0.23.1](https://github.com/conda/rattler/compare/rattler_lock-v0.23.0...rattler_lock-v0.23.1) - 2025-04-15

### Added

- add resolver options to lock-file ([#1255](https://github.com/conda/rattler/pull/1255))

## [0.23.0](https://github.com/conda/rattler/compare/rattler_lock-v0.22.49...rattler_lock-v0.23.0) - 2025-04-10

### Added

- add source location ([#1216](https://github.com/conda/rattler/pull/1216))

## [0.22.49](https://github.com/conda/rattler/compare/rattler_lock-v0.22.48...rattler_lock-v0.22.49) - 2025-04-04

### Other

- add the remove_from_backup function and update the prefix ([#1155](https://github.com/conda/rattler/pull/1155))

## [0.22.48](https://github.com/conda/rattler/compare/rattler_lock-v0.22.47...rattler_lock-v0.22.48) - 2025-03-14

### Other

- updated the following local packages: rattler_conda_types

## [0.22.47](https://github.com/conda/rattler/compare/rattler_lock-v0.22.46...rattler_lock-v0.22.47) - 2025-03-10

### Other

- release ([#1137](https://github.com/conda/rattler/pull/1137))

## [0.22.46](https://github.com/conda/rattler/compare/rattler_lock-v0.22.45...rattler_lock-v0.22.46) - 2025-02-28

### Fixed

- roundtrip of arch/platform in lock files (#1124)

## [0.22.45](https://github.com/conda/rattler/compare/rattler_lock-v0.22.44...rattler_lock-v0.22.45) - 2025-02-27

### Fixed

- clippy lint (#1105)

## [0.22.44](https://github.com/conda/rattler/compare/rattler_lock-v0.22.43...rattler_lock-v0.22.44) - 2025-02-25

### Other

- updated the following local packages: rattler_conda_types

## [0.22.43](https://github.com/conda/rattler/compare/rattler_lock-v0.22.42...rattler_lock-v0.22.43) - 2025-02-18

### Other

- update Cargo.toml dependencies

## [0.22.42](https://github.com/conda/rattler/compare/rattler_lock-v0.22.41...rattler_lock-v0.22.42) - 2025-02-06

### Other

- bump rust 1.84.1 (#1053)

## [0.22.41](https://github.com/conda/rattler/compare/rattler_lock-v0.22.40...rattler_lock-v0.22.41) - 2025-02-03

### Other

- updated the following local packages: rattler_conda_types

## [0.22.40](https://github.com/conda/rattler/compare/rattler_lock-v0.22.39...rattler_lock-v0.22.40) - 2025-01-23

### Other

- updated the following local packages: rattler_conda_types

## [0.22.39](https://github.com/conda/rattler/compare/rattler_lock-v0.22.38...rattler_lock-v0.22.39) - 2025-01-09

### Added

- add a check function for empty lockfiles (#1023)
- Match GenericVirtualPackage with MatchSpec (#1016)

## [0.22.38](https://github.com/conda/rattler/compare/rattler_lock-v0.22.37...rattler_lock-v0.22.38) - 2025-01-09

### Other

- updated the following local packages: rattler_conda_types

## [0.22.37](https://github.com/conda/rattler/compare/rattler_lock-v0.22.36...rattler_lock-v0.22.37) - 2025-01-08

### Other

- updated the following local packages: file_url, rattler_conda_types, rattler_digest

## [0.22.36](https://github.com/conda/rattler/compare/rattler_lock-v0.22.35...rattler_lock-v0.22.36) - 2024-12-20

### Other

- updated the following local packages: rattler_conda_types

## [0.22.35](https://github.com/conda/rattler/compare/rattler_lock-v0.22.34...rattler_lock-v0.22.35) - 2024-12-17

### Other

- update Cargo.toml dependencies

## [0.22.34](https://github.com/conda/rattler/compare/rattler_lock-v0.22.33...rattler_lock-v0.22.34) - 2024-12-13

### Other

- updated the following local packages: rattler_conda_types

## [0.22.33](https://github.com/conda/rattler/compare/rattler_lock-v0.22.32...rattler_lock-v0.22.33) - 2024-12-12

### Fixed
- merge purls from matching records in lock-file ([#965](https://github.com/conda/rattler/pull/965))

## [0.22.32](https://github.com/conda/rattler/compare/rattler_lock-v0.22.31...rattler_lock-v0.22.32) - 2024-11-30

### Other

- updated the following local packages: file_url, rattler_conda_types

## [0.22.31](https://github.com/conda/rattler/compare/rattler_lock-v0.22.30...rattler_lock-v0.22.31) - 2024-11-18

### Other

- updated the following local packages: rattler_conda_types

## [0.22.30](https://github.com/conda/rattler/compare/rattler_lock-v0.22.29...rattler_lock-v0.22.30) - 2024-11-14

### Other

- updated the following local packages: rattler_conda_types

## [0.22.29](https://github.com/conda/rattler/compare/rattler_lock-v0.22.28...rattler_lock-v0.22.29) - 2024-11-04

### Added

- use python_site_packages_path field when available for installing noarch: python packages, CEP-17 ([#909](https://github.com/conda/rattler/pull/909))
- bump pep crates in rattler ([#918](https://github.com/conda/rattler/pull/918))
- add debug trait to LockFile struct in rattler_lock ([#922](https://github.com/conda/rattler/pull/922))

## [0.22.28](https://github.com/conda/rattler/compare/rattler_lock-v0.22.27...rattler_lock-v0.22.28) - 2024-10-21

### Other

- updated the following local packages: file_url

## [0.22.27](https://github.com/conda/rattler/compare/rattler_lock-v0.22.26...rattler_lock-v0.22.27) - 2024-10-07

### Other

- updated the following local packages: rattler_conda_types

## [0.22.26](https://github.com/conda/rattler/compare/rattler_lock-v0.22.25...rattler_lock-v0.22.26) - 2024-10-03

### Other

- updated the following local packages: rattler_conda_types

## [0.22.25](https://github.com/conda/rattler/compare/rattler_lock-v0.22.24...rattler_lock-v0.22.25) - 2024-09-23

### Other

- updated the following local packages: rattler_conda_types

## [0.22.24](https://github.com/conda/rattler/compare/rattler_lock-v0.22.23...rattler_lock-v0.22.24) - 2024-09-09

### Other

- updated the following local packages: rattler_conda_types

## [0.22.23](https://github.com/conda/rattler/compare/rattler_lock-v0.22.22...rattler_lock-v0.22.23) - 2024-09-05

### Fixed
- typos ([#849](https://github.com/conda/rattler/pull/849))

## [0.22.22](https://github.com/conda/rattler/compare/rattler_lock-v0.22.21...rattler_lock-v0.22.22) - 2024-09-03

### Other
- make PackageCache multi-process safe ([#837](https://github.com/conda/rattler/pull/837))

## [0.22.21](https://github.com/conda/rattler/compare/rattler_lock-v0.22.20...rattler_lock-v0.22.21) - 2024-09-02

### Added
- Add support for `CONDA_OVERRIDE_CUDA` ([#818](https://github.com/conda/rattler/pull/818))

## [0.22.20](https://github.com/conda/rattler/compare/rattler_lock-v0.22.19...rattler_lock-v0.22.20) - 2024-08-16

### Added
- default construct marker-tree ([#825](https://github.com/conda/rattler/pull/825))

## [0.22.19](https://github.com/conda/rattler/compare/rattler_lock-v0.22.18...rattler_lock-v0.22.19) - 2024-08-15

### Fixed
- move more links to the conda org from conda-incubator ([#816](https://github.com/conda/rattler/pull/816))

### Other
- change links from conda-incubator to conda ([#813](https://github.com/conda/rattler/pull/813))
- update banner ([#808](https://github.com/conda/rattler/pull/808))

## [0.22.18](https://github.com/baszalmstra/rattler/compare/rattler_lock-v0.22.17...rattler_lock-v0.22.18) - 2024-08-06

### Other
- updated the following local packages: rattler_conda_types

## [0.22.17](https://github.com/baszalmstra/rattler/compare/rattler_lock-v0.22.16...rattler_lock-v0.22.17) - 2024-08-02

### Other
- mark some crates 1.0 ([#789](https://github.com/baszalmstra/rattler/pull/789))

## [0.22.16](https://github.com/conda/rattler/compare/rattler_lock-v0.22.15...rattler_lock-v0.22.16) - 2024-07-23

### Other
- updated the following local packages: rattler_conda_types

## [0.22.15](https://github.com/conda/rattler/compare/rattler_lock-v0.22.14...rattler_lock-v0.22.15) - 2024-07-23

### Other
- updated the following local packages: rattler_conda_types

## [0.22.14](https://github.com/conda/rattler/compare/rattler_lock-v0.22.13...rattler_lock-v0.22.14) - 2024-07-15

### Other
- bump dependencies and remove unused ones ([#771](https://github.com/conda/rattler/pull/771))

## [0.22.13](https://github.com/conda/rattler/compare/rattler_lock-v0.22.12...rattler_lock-v0.22.13) - 2024-07-08

### Added
- Only save md5 in lock file if no sha256 is present ([#764](https://github.com/conda/rattler/pull/764))
- return pybytes for sha256 and md5 everywhere and use md5 hash for legacy bz2 md5 ([#752](https://github.com/conda/rattler/pull/752))
- add direct url repodata building ([#725](https://github.com/conda/rattler/pull/725))

### Fixed
- lock file stability issues with PyPI types ([#761](https://github.com/conda/rattler/pull/761))
- errors should not contain trailing punctuation ([#763](https://github.com/conda/rattler/pull/763))

### Other
- revert only save md5 in lock file if no sha256 is present ([#766](https://github.com/conda/rattler/pull/766))

## [0.22.12](https://github.com/conda/rattler/compare/rattler_lock-v0.22.11...rattler_lock-v0.22.12) - 2024-06-06

### Added
- serialize packages from lock file individually ([#728](https://github.com/conda/rattler/pull/728))

## [0.22.11](https://github.com/baszalmstra/rattler/compare/rattler_lock-v0.22.10...rattler_lock-v0.22.11) - 2024-06-04

### Other
- updated the following local packages: file_url, rattler_conda_types

## [0.22.10](https://github.com/conda/rattler/compare/rattler_lock-v0.22.9...rattler_lock-v0.22.10) - 2024-06-03

### Other
- updated the following local packages: rattler_conda_types

## [0.22.9](https://github.com/conda/rattler/compare/rattler_lock-v0.22.8...rattler_lock-v0.22.9) - 2024-05-28

### Added
- add run exports to package data ([#671](https://github.com/conda/rattler/pull/671))

### Other
- bump ([#683](https://github.com/conda/rattler/pull/683))

## [0.22.8](https://github.com/conda/rattler/compare/rattler_lock-v0.22.7...rattler_lock-v0.22.8) - 2024-05-27

### Added
- removed Ord and more ([#673](https://github.com/conda/rattler/pull/673))
- always store purls as a key in lock file ([#669](https://github.com/conda/rattler/pull/669))

## [0.22.7](https://github.com/conda/rattler/compare/rattler_lock-v0.22.6...rattler_lock-v0.22.7) - 2024-05-14

### Other
- bump pep crates ([#661](https://github.com/conda/rattler/pull/661))

## [0.22.6](https://github.com/conda/rattler/compare/rattler_lock-v0.22.5...rattler_lock-v0.22.6) - 2024-05-13

### Added
- high level repodata access ([#560](https://github.com/conda/rattler/pull/560))

### Other
- update README.md

## [0.22.5](https://github.com/conda/rattler/compare/rattler_lock-v0.22.4...rattler_lock-v0.22.5) - 2024-05-06

### Other
- updated the following local packages: rattler_conda_types

## [0.22.4](https://github.com/conda/rattler/compare/rattler_lock-v0.22.3...rattler_lock-v0.22.4) - 2024-04-30

### Added
- adds pypi indexes to the lock-file ([#626](https://github.com/conda/rattler/pull/626))

## [0.22.3](https://github.com/conda/rattler/compare/rattler_lock-v0.22.2...rattler_lock-v0.22.3) - 2024-04-25

### Fixed
- compare `UrlOrPath` ([#618](https://github.com/conda/rattler/pull/618))
- parse absolute paths on Windows correctly in lockfiles ([#616](https://github.com/conda/rattler/pull/616))

## [0.22.2](https://github.com/conda/rattler/compare/rattler_lock-v0.22.1...rattler_lock-v0.22.2) - 2024-04-19

### Other
- update dependencies incl. reqwest ([#606](https://github.com/conda/rattler/pull/606))

## [0.22.1](https://github.com/baszalmstra/rattler/compare/rattler_lock-v0.22.0...rattler_lock-v0.22.1) - 2024-04-05

### Other
- updated the following local packages: rattler_conda_types

## [0.22.0](https://github.com/conda/rattler/compare/rattler_lock-v0.21.0...rattler_lock-v0.22.0) - 2024-03-30

### Added
- editable pypi packages ([#581](https://github.com/conda/rattler/pull/581))

## [0.21.0](https://github.com/conda/rattler/compare/rattler_lock-v0.20.2...rattler_lock-v0.21.0) - 2024-03-21

### Added
- allow passing pypi paths ([#572](https://github.com/conda/rattler/pull/572))

## [0.20.2](https://github.com/conda/rattler/compare/rattler_lock-v0.20.1...rattler_lock-v0.20.2) - 2024-03-14

### Other
- add pixi badge ([#563](https://github.com/conda/rattler/pull/563))

## [0.20.1](https://github.com/conda/rattler/compare/rattler_lock-v0.20.0...rattler_lock-v0.20.1) - 2024-03-08

### Fixed
- chrono deprecation warnings ([#558](https://github.com/conda/rattler/pull/558))

## [0.20.0](https://github.com/conda/rattler/compare/rattler_lock-v0.19.0...rattler_lock-v0.20.0) - 2024-03-06

### Added
- sort extras by name and urls by filename ([#540](https://github.com/conda/rattler/pull/540))

### Fixed
- dont use workspace dependencies for local crates ([#546](https://github.com/conda/rattler/pull/546))

### Other
- every crate should have its own version ([#557](https://github.com/conda/rattler/pull/557))
- bump pep508_rs and pep440_rs ([#549](https://github.com/conda/rattler/pull/549))

## [0.19.0](https://github.com/baszalmstra/rattler/compare/rattler_lock-v0.18.0...rattler_lock-v0.19.0) - 2024-02-26
